@@ -20,7 +20,7 @@ sub begin :Private { }
 sub foo  :PathPart('chained/foo')  :CaptureArgs(1) :Chained('/') {
     my ( $self, $c, @args ) = @_;
     die "missing argument" unless @args;
-    die "more than 1 argument" if @args > 1;
+    die "more than 1 argument: got @args" if @args > 1;
 }
 sub endpoint  :PathPart('end')  :Chained('/action/chained/foo')  :Args(1) { }
 
