@@ -5,7 +5,7 @@ use base 'TestApp::Controller::Action';
 
 sub uri_check : Private {
     my ( $self, $c ) = @_;
-    $c->res->body( $c->uri_for('foo/bar')->path );
+    $c->res->body( $c->uri_for('foo/bar')->rel($c->req->base)->path );
 }
 
 1;
