@@ -5,7 +5,9 @@ use base qw[TestApp::View::Dump];
 
 sub process {
     my ( $self, $c ) = @_;
-    return $self->SUPER::process( $c, $c->request );
+    my $r = $c->request;
+    local $r->{env};
+    return $self->SUPER::process( $c, $r );
 }
 
 1;
